# Generated by Django 4.0.4 on 2022-05-25 07:50

import common.files.upload
import common.validators.files
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('chat', '0007_alter_chat_name'),
        ('registration', '0008_create_bot_user'),
        ('roleplay', '0007_alter_playerinsession_options_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Campaign',
            fields=[
                ('entry_created_at', models.DateTimeField(auto_now_add=True, verbose_name='entry created at')),
                ('entry_updated_at', models.DateTimeField(auto_now=True, verbose_name='entry updated at')),
                ('id', models.BigAutoField(db_index=True, primary_key=True, serialize=False, verbose_name='identifier')),
                ('name', models.CharField(max_length=50, verbose_name='name')),
                ('description', models.TextField(blank=True, verbose_name='description')),
                ('gm_info', models.TextField(blank=True, help_text='information specific to the game master.', verbose_name='game master information')),
                ('summary', models.CharField(blank=True, max_length=254, verbose_name='summary')),
                ('system', models.PositiveSmallIntegerField(choices=[(0, 'Pathfinder 1e'), (1, 'Dungeons & Dragons 3.5')], verbose_name='system')),
                ('cover_image', models.ImageField(blank=True, upload_to=common.files.upload.default_upload_to, validators=[common.validators.files.validate_file_size], verbose_name='cover image')),
                ('is_public', models.BooleanField(default=False, help_text='can this campaign be accessed by anyone?', verbose_name='public')),
                ('start_date', models.DateField(blank=True, null=True, verbose_name='start date')),
                ('end_date', models.DateField(blank=True, null=True, verbose_name='end date')),
                ('discord_channel_id', models.CharField(blank=True, max_length=254, verbose_name='identifier for discord channel')),
                ('chat', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='campaign_set', to='chat.chat', verbose_name='chat')),
                ('owner', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='campaign_owned_set', to=settings.AUTH_USER_MODEL, verbose_name='owner')),
            ],
            options={
                'verbose_name': 'campaign',
                'verbose_name_plural': 'campaigns',
                'ordering': ['-entry_created_at', 'name'],
            },
        ),
        migrations.CreateModel(
            name='PlayerInCampaign',
            fields=[
                ('entry_created_at', models.DateTimeField(auto_now_add=True, verbose_name='entry created at')),
                ('entry_updated_at', models.DateTimeField(auto_now=True, verbose_name='entry updated at')),
                ('id', models.BigAutoField(db_index=True, primary_key=True, serialize=False, verbose_name='identifier')),
                ('is_game_master', models.BooleanField(default=False, verbose_name='game master')),
                ('campaign', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='player_in_campaign_set', to='roleplay.campaign', verbose_name='campaign')),
                ('user', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='player_in_campaign_set', to=settings.AUTH_USER_MODEL, verbose_name='user')),
            ],
            options={
                'verbose_name': 'player in campaign',
                'verbose_name_plural': 'players in campaign',
                'ordering': ['-entry_created_at', 'user__username'],
                'unique_together': {('user', 'campaign')},
            },
        ),
        migrations.AlterModelOptions(
            name='session',
            options={'ordering': ['-next_game', 'name', '-entry_updated_at'], 'verbose_name': 'session', 'verbose_name_plural': 'sessions'},
        ),
        migrations.RemoveField(
            model_name='session',
            name='chat',
        ),
        migrations.RemoveField(
            model_name='session',
            name='players',
        ),
        migrations.RemoveField(
            model_name='session',
            name='system',
        ),
        migrations.RemoveField(
            model_name='session',
            name='world',
        ),
        migrations.AddField(
            model_name='session',
            name='description',
            field=models.TextField(blank=True, verbose_name='description'),
        ),
        migrations.AddField(
            model_name='session',
            name='gm_info',
            field=models.TextField(blank=True, help_text='information specific to the game master.', verbose_name='game master info'),
        ),
        migrations.AlterField(
            model_name='place',
            name='site_type',
            field=models.PositiveSmallIntegerField(choices=[(0, 'house'), (1, 'town'), (2, 'village'), (3, 'city'), (4, 'metropolis'), (5, 'forest'), (6, 'hills'), (7, 'mountains'), (8, 'mines'), (9, 'river'), (10, 'sea'), (11, 'desert'), (12, 'tundra'), (13, 'unusual'), (14, 'island'), (15, 'country'), (16, 'continent'), (17, 'world'), (18, 'ocean'), (19, 'temple'), (20, 'ruins')], default=1, verbose_name='site type'),
        ),
        migrations.AlterField(
            model_name='session',
            name='image',
            field=models.ImageField(blank=True, upload_to=common.files.upload.default_upload_to, validators=[common.validators.files.validate_file_size], verbose_name='cover'),
        ),
        migrations.AlterField(
            model_name='session',
            name='name',
            field=models.CharField(max_length=100, verbose_name='title'),
        ),
        migrations.AlterField(
            model_name='session',
            name='plot',
            field=models.CharField(blank=True, help_text='one line summary.', max_length=254, verbose_name='plot'),
        ),
        migrations.DeleteModel(
            name='PlayerInSession',
        ),
        migrations.AddField(
            model_name='campaign',
            name='place',
            field=models.ForeignKey(limit_choices_to={'site_type': 17}, on_delete=django.db.models.deletion.CASCADE, related_name='campaign_set', to='roleplay.place', verbose_name='world'),
        ),
        migrations.AddField(
            model_name='campaign',
            name='users',
            field=models.ManyToManyField(related_name='campaign_set', through='roleplay.PlayerInCampaign', to=settings.AUTH_USER_MODEL, verbose_name='players'),
        ),
        migrations.AddField(
            model_name='session',
            name='campaign',
            field=models.ForeignKey(default=1, on_delete=django.db.models.deletion.CASCADE, related_name='session_set', to='roleplay.campaign', verbose_name='campaign'),
            preserve_default=False,
        ),
    ]
